@@ -101,7 +101,11 @@ class ClockTimer:
         for i, (sec, sound) in enumerate(sounds.items()):
             spend_time = secs[i] - (0 if i == 0 else secs[i - 1])
             message = inner_str(sound.message, {"count": count})
-            notify_all(title=self.title, message=message, spend_time=spend_time)
+            notify_all(
+                title=self.title,
+                message=message,
+                spend_time=spend_time,
+                is_first=sec == 0 and count == 1)
 
             ps.append(sound.run())
             sound.confirm_f()
