@@ -121,7 +121,7 @@ def specified_time_main(opt, args) -> None:
 
     try:
         message = f"Specified time is passed(sec={time_sec})."
-        notify_all(title="Exclock", message=message, spend_time=time_sec)
+        notify_all(title="Exclock", message=message, spend_time=time_sec, is_first=False)
 
         warning_sound_filename = get_real_sound_filename("__warning.mp3")
         p = vlc.MediaPlayer(warning_sound_filename)
