@@ -1,12 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import os
 from os.path import basename as _path_basename
 from pathlib import Path
+from shlex import quote
 from time import sleep as time_sleep
 from typing import List, Tuple
 
-from notifypy import Notify
 from tqdm import tqdm
 
 ASSET_DIR_IN_PROG = Path(__file__).parent.absolute().joinpath("assets")
@@ -16,6 +17,8 @@ ASSET_DIR_IN_SYS = Path(Path.home(), ".exclock")
 CLOCK_DIR_IN_SYS = ASSET_DIR_IN_SYS / "clock"
 SOUND_DIR_IN_SYS = ASSET_DIR_IN_SYS / "sound"
 
+DEFAULT_IMAGE_PATH = ASSET_DIR_IN_PROG / "icon.png"
+
 
 def get_clock_basenames() -> List[str]:
     clock_paths = set(CLOCK_DIR_IN_SYS.glob("**/*"))
@@ -143,25 +146,21 @@ def get_real_sound_filename(path_: str) -> str:
     return str(SOUND_DIR_IN_PROG / path_name)
 
 
-def notify(title: str, message: str, application_name: str = "Exclock") -> None:
-    notification = Notify()
-    notification.application_name = "Exclock"
-    notification.title = title
-    notification.message = message
-    notification.send()
+def notify(title: str, message: str) -> None:
+    message = quote(title + "\n" + message)
+    os.system(f'(xmessage -nearmouse {message}) &')
 
 
 def notify_all(
     title: str,
     message: str,
     spend_time: int,
-    application_name: str = "Exclock",
+    is_first: bool,
 ) -> None:
     tqdm_f = (lambda i: i) if spend_time == 0 else lambda i: tqdm(
         i, bar_format="{l_bar}{bar}| {n_fmt}/{total_fmt} ")
     for _ in tqdm_f(range(spend_time)):
         time_sleep(1)
 
-    notify(title=title, message=message, application_name=application_name)
-
-    print(message)
+    if not is_first:
+        notify(title=title, message=message)
